#ifndef BRIDGE_H
#define BRIDGE_H

#include <QObject>
#include <QMutex>
#include <QAbstractSocket>

class QTcpSocket;
class HidInterface;


class Bridge : public QObject
{
    Q_OBJECT

    typedef enum {
        START_1,
        START_2,
        START_3,
        LEN_1,
        LEN_2,
        LEN_3,
        LEN_4,
        DATA
    } STATE;

public:
    Bridge(HidInterface* hid, QObject *parent = 0);
    ~Bridge();

public slots:
    void tcp_newConnection(QTcpSocket* socket);
    void tcp_lostConnection();
    void tcp_readyRead();
    void tcp_error(QAbstractSocket::SocketError err);

    void hid_lostConnection();
    void hid_readData( QByteArray data );

private:
    void tcp_parsePackage( const QByteArray& package);

    HidInterface*   m_hid;
    QTcpSocket*     m_socket;

    QMutex          m_parseProtect;
    QByteArray      m_data;
    uint            m_dataIndex;
    STATE           m_state;
    uint            m_size;
};

#endif // BRIDGE_H
