#include "TcpInterface.h"
#include "Bridge.h"

TcpInterface::TcpInterface(QTcpSocket* socket, Bridge* bridge, QObject *parent)
    : QThread(parent)
    , m_socket(socket)
    , m_bridge(bridge)
{
    this->start();

    if(this != QThread::currentThread ())
        m_device->moveToThread(this);
}



void TcpInterface::run()
{
    while(m_active)
    {
        m_socket->waitForReadyRead(-1);

        if(m_socket->bytesAvailable())
        {
            QByteArray data = m_socket->readAll();
            parsePackage(data);
        }
    }
}


void TcpInterface::parsePackage( const QByteArray& package)
{
    uchar byte = 0;
    for(int i = 0; i < package.size(); i++)
    {
        byte = package.at(i);
        switch(m_state)
        {
        case START_1:
            if(byte == 0xAA)
                m_state = START_2;
            break;
        case START_2:
            if(byte == 0x55)
                m_state = START_3;
            else
                m_state = START_1;
            break;
        case START_3:
            if(byte == 0xA5)
                m_state = LEN_1;
            else
                m_state = START_1;
            break;
        case LEN_1:
            m_size = 0;
            m_size += ((uint)byte) << 24;
            m_state = LEN_2;
            break;
        case LEN_2:
            m_size += ((uint)byte) << 16;
            m_state = LEN_3;
            break;
        case LEN_3:
            m_size += ((uint)byte) << 8;
            m_state = LEN_4;
            break;
        case LEN_4:
            m_size += ((uint)byte);
            m_state = DATA;
            m_data = QByteArray(m_size, (char)0);
            m_dataIndex = 0;
            break;
        case DATA:
            m_data[m_dataIndex++] = byte;
            if(m_dataIndex == m_size){
                qDebug() << "TCP -> HID - " << m_data.toHex();
                m_hid->write(m_data);
                m_state = START_1;
            }
            break;
        }
    }
}
